==> un-applet_1.3.2_all.tar.bz2: un-applet_1.3.2_all/usr/share/un-applet/Icon.py <==
# -*- coding: utf-8 -*-

import Tkinter
import ConfigHandler
import os
import sys

PROGRAMDIR = os.path.abspath(sys.path[0])
ICONDIR = os.path.join(PROGRAMDIR, 'icons')
CONFIGDIR = os.path.join(os.getenv('HOME'), '.config', 'un-applet')


FALLBACK_IMG = ('iVBORw0KGgoAAAANSUhEUgAAABQAAAAUCAYAAACNiR0NAAAABmJLR0QA/wD/AP'
                '+gvaeTAAAACXBIWXMAAA3XAAAN1wFCKJt4AAAAB3RJTUUH4AMSFhg6O5zKzwAA'
                'Ad1JREFUOMutlM9rE1EQx78zs+lqEnoIibsoDSLGg5JL+yeUesnF+OsP0YOgHh'
                'sIOfnjaiTtzYP9G+rBXiOkiKcSAsIulLpkybLB3X0eYrbbZtVgdy5v3rzH533n'
                'MTPU7rQeA/iAbOwZ2p2WsixLXdRc11XtTktpAGAYBgaDQfwMEcXrn/zzsVqtBg'
                'DQ5pB6vZ5JzjHw8NuXc0cEYQYzg4jBImA6jTFrv1cCk6BSNs4CAeCasfZfqhSi'
                '2Ocs0mSW5YBHpTKOSmV4+58AAN+37mJ481YKkBeBxLRw8Ur3HQDAuv8A494OQt'
                'tGfnNzOYWSCM6t2LwHc+8jAOD4yVOEJz+wcuf2cgqTwaQFwyH0jfXZ53seeHV1'
                '4Y6kKeQUhc6bt3BevUbkuqh+PYyVjns7ZwtMZLEOkwoDy8K4+x7+5wMUHz1Esd'
                'mEZpq4cXKcmoUQpwAp8YppovTi+fJlIylAEYbne7PKZ4Ewg5hnPjFIGEwCFp7t'
                '5x1DAkprvbWr17Pt5dFo9Ndp8q/JU6lUToG2baNarV5ImW3bMXC7t9t9mdHE3i'
                'YAaDQal6MoMhzHyU8mk7zv+/kgCC6FYaiHYbiilNKUUkJEiogCZv4pItNcLufp'
                'uu4VCoXJdDq1+v2+8wtpW8j8DxgmlAAAAABJRU5ErkJggg==')

class Icon(Tkinter.PhotoImage):
    def __init__(self, imgname):
        Tkinter.PhotoImage.__init__(self)
        self._imgname = None
        self.image(imgname)

    def image(self, imgname=None):
        if imgname is None:
            return(self._imgname)
        self._imgname = imgname
        imgname, icon_theme = imgname + '.png', ConfigHandler.get('ICON_THEME')
        try:
            full = os.path.join(CONFIGDIR, icon_theme, imgname)
            if not os.path.isfile(full):
                full = os.path.join(ICONDIR, icon_theme, imgname)
                if not os.path.isfile(full):
                    full = os.path.join(ICONDIR, imgname)
            self.configure(file=full, data='')
        except:
            self.configure(file='', data=FALLBACK_IMG)

==> un-applet_1.5_all.tar.bz2: un-applet_1.5_all/usr/share/un-applet/Icon.py <==
# -*- coding: utf-8 -*-

import os
import Tkinter

import ConfigHandler
import libmisc

FALLBACK_IMG = ('iVBORw0KGgoAAAANSUhEUgAAABQAAAAUCAYAAACNiR0NAAAABmJLR0QA/wD/AP'
                '+gvaeTAAAACXBIWXMAAA3XAAAN1wFCKJt4AAAAB3RJTUUH4AMSFhg6O5zKzwAA'
                'Ad1JREFUOMutlM9rE1EQx78zs+lqEnoIibsoDSLGg5JL+yeUesnF+OsP0YOgHh'
                'sIOfnjaiTtzYP9G+rBXiOkiKcSAsIulLpkybLB3X0eYrbbZtVgdy5v3rzH533n'
                'MTPU7rQeA/iAbOwZ2p2WsixLXdRc11XtTktpAGAYBgaDQfwMEcXrn/zzsVqtBg'
                'DQ5pB6vZ5JzjHw8NuXc0cEYQYzg4jBImA6jTFrv1cCk6BSNs4CAeCasfZfqhSi'
                '2Ocs0mSW5YBHpTKOSmV4+58AAN+37mJ481YKkBeBxLRw8Ur3HQDAuv8A494OQt'
                'tGfnNzOYWSCM6t2LwHc+8jAOD4yVOEJz+wcuf2cgqTwaQFwyH0jfXZ53seeHV1'
                '4Y6kKeQUhc6bt3BevUbkuqh+PYyVjns7ZwtMZLEOkwoDy8K4+x7+5wMUHz1Esd'
                'mEZpq4cXKcmoUQpwAp8YppovTi+fJlIylAEYbne7PKZ4Ewg5hnPjFIGEwCFp7t'
                '5x1DAkprvbWr17Pt5dFo9Ndp8q/JU6lUToG2baNarV5ImW3bMXC7t9t9mdHE3i'
                'YAaDQal6MoMhzHyU8mk7zv+/kgCC6FYaiHYbiilNKUUkJEiogCZv4pItNcLufp'
                'uu4VCoXJdDq1+v2+8wtpW8j8DxgmlAAAAABJRU5ErkJggg==')

class Icon(Tkinter.PhotoImage):
    def __init__(self, imgname):
        Tkinter.PhotoImage.__init__(self)
        self._imgname = None
        self.image(imgname)

    def image(self, imgname=None):
        if imgname is None:
            return(self._imgname)
        self._imgname = imgname
        imgname, icon_theme = imgname + '.png', ConfigHandler.get('ICON_THEME')
        try:
            full = os.path.join(libmisc.CONFIGDIR, icon_theme, imgname)
            if not os.path.isfile(full):
                full = os.path.join(libmisc.ICONDIR, icon_theme, imgname)
                if not os.path.isfile(full):
                    full = os.path.join(libmisc.ICONDIR, imgname)
            self.configure(file=full, data='')
        except:
            self.configure(file='', data=FALLBACK_IMG)
